@@ -14,15 +14,14 @@ from compas.geometry.basic import dot_vectors
 from compas.geometry.basic import multiply_matrix_vector
 from compas.geometry.basic import length_vector
 from compas.geometry.basic import allclose
-from compas.geometry.basic import transpose_matrix
 from compas.geometry.basic import multiply_matrices
+from compas.geometry.basic import transpose_matrix
 from compas.geometry.basic import norm_vector
 
 from compas.geometry.transformations import _EPS
 from compas.geometry.transformations import _SPEC2TUPLE
 from compas.geometry.transformations import _NEXT_SPEC
 
-
 __all__ = [
     'matrix_determinant',
     'matrix_inverse',
@@ -32,6 +31,8 @@ __all__ = [
     'identity_matrix',
 
     'matrix_from_frame',
+    'matrix_from_frame_to_frame',
+    'matrix_change_basis',
     'matrix_from_euler_angles',
     'matrix_from_axis_and_angle',
     'matrix_from_axis_angle_vector',
@@ -61,6 +62,7 @@ __all__ = [
     'translation_from_matrix',
 ]
 
+
 def matrix_determinant(M, check=True):
     """Calculates the determinant of a square matrix M.
 
@@ -397,6 +399,55 @@ def matrix_from_frame(frame):
     return M
 
 
+def matrix_from_frame_to_frame(frame_from, frame_to):
+    """Computes a transformation between two frames.
+
+    This transformation allows to transform geometry from one Cartesian
+    coordinate system defined by "frame_from" to another Cartesian
+    coordinate system defined by "frame_to".
+
+    Parameters
+    ----------
+    frame_from : :class:`Frame`
+        A frame defining the original Cartesian coordinate system
+    frame_to : :class:`Frame`
+        A frame defining the targeted Cartesian coordinate system
+
+    Examples
+    --------
+    >>> f1 = Frame([2, 2, 2], [0.12, 0.58, 0.81], [-0.80, 0.53, -0.26])
+    >>> f2 = Frame([1, 1, 1], [0.68, 0.68, 0.27], [-0.67, 0.73, -0.15])
+    >>> T = matrix_from_frame_to_frame(f1, f2)
+    """
+    T1 = matrix_from_frame(frame_from)
+    T2 = matrix_from_frame(frame_to)
+    return multiply_matrices(T2, matrix_inverse(T1))
+
+
+def matrix_change_basis(frame_from, frame_to):
+    """Computes a change of basis transformation between two frames.
+
+    A basis change is essentially a remapping of geometry from one
+    coordinate system to another.
+
+    Parameters
+    ----------
+    frame_from : :class:`Frame`
+        A frame defining the original Cartesian coordinate system
+    frame_to : :class:`Frame`
+        A frame defining the targeted Cartesian coordinate system
+
+    Example:
+    >>> from compas.geometry import Point, Frame
+    >>> f1 = Frame([2, 2, 2], [0.12, 0.58, 0.81], [-0.80, 0.53, -0.26])
+    >>> f2 = Frame([1, 1, 1], [0.68, 0.68, 0.27], [-0.67, 0.73, -0.15])
+    >>> T = matrix_change_basis(f1, f2)
+    """
+    T1 = matrix_from_frame(frame_from)
+    T2 = matrix_from_frame(frame_to)
+    return multiply_matrices(matrix_inverse(T2), T1)
+
+
 def matrix_from_euler_angles(euler_angles, static=True, axes='xyz'):
     """Calculates a rotation matrix from Euler angles.
 
@@ -1281,5 +1332,7 @@ def axis_angle_from_quaternion(q):
 # ==============================================================================
 
 if __name__ == "__main__":
-
-    pass
+    import doctest
+    from compas.geometry import Frame
+    from compas.geometry import Transformation
+    doctest.testmod(globs=globals())
