@@ -38,5 +38,4 @@ class ThreadedServer(object):
 
 if __name__ == '__main__':
 
-    server = ThreadedServer()
-    server.start()
+    pass
