@@ -1,6 +1,6 @@
 """
 ********************************************************************************
-Plotters
+compas_plotters
 ********************************************************************************
 
 .. currentmodule:: compas_plotters
@@ -13,7 +13,6 @@ Classes
     :toctree: generated/
     :nosignatures:
 
-    Plotter
     NetworkPlotter
     MeshPlotter
 
